@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "notesagentalarmdialog.h"
 #include "notesagentnotedialog.h"
@@ -51,9 +38,9 @@ NotesAgentAlarmDialog::NotesAgentAlarmDialog(QWidget *parent)
     setWindowTitle(i18nc("@title:window", "Alarm"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("knotes")));
     setAttribute(Qt::WA_DeleteOnClose);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
-    QVBoxLayout *vbox = new QVBoxLayout;
+    auto *vbox = new QVBoxLayout;
     mainLayout->addLayout(vbox);
 
     mCurrentDateTime = new QLabel(this);
@@ -97,7 +84,7 @@ void NotesAgentAlarmDialog::slotCustomContextMenuRequested(const QPoint &pos)
         return;
     }
     Q_UNUSED(pos);
-    QMenu *entriesContextMenu = new QMenu(this);
+    auto *entriesContextMenu = new QMenu(this);
     QAction *removeAlarm = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove Alarm"), entriesContextMenu);
     connect(removeAlarm, &QAction::triggered, this, &NotesAgentAlarmDialog::slotRemoveAlarm);
     QAction *showNote = new QAction(i18n("Show Note..."), entriesContextMenu);
@@ -147,7 +134,7 @@ void NotesAgentAlarmDialog::slotShowNote()
     //deleted on close
     const Akonadi::Item::Id id = mListWidget->currentItemId();
     if (id != -1) {
-        NotesAgentNoteDialog *dlg = new NotesAgentNoteDialog;
+        auto *dlg = new NotesAgentNoteDialog;
         dlg->setNoteId(id);
         dlg->show();
     }
@@ -159,7 +146,7 @@ void NotesAgentAlarmDialog::slotRemoveAlarm()
         const Akonadi::Item::Id id = mListWidget->currentItemId();
         if (id != -1) {
             Akonadi::Item item(id);
-            Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+            auto *job = new Akonadi::ItemFetchJob(item, this);
             job->fetchScope().fetchAttribute<NoteShared::NoteAlarmAttribute>();
             connect(job, &Akonadi::ItemFetchJob::result, this, &NotesAgentAlarmDialog::slotFetchItem);
         }
@@ -172,12 +159,12 @@ void NotesAgentAlarmDialog::slotFetchItem(KJob *job)
         qCDebug(NOTESAGENT_LOG) << "fetch item failed " << job->errorString();
         return;
     }
-    Akonadi::ItemFetchJob *itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
+    auto *itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
     Akonadi::Item::List items = itemFetchJob->items();
     if (!items.isEmpty()) {
         Akonadi::Item item = items.first();
         item.removeAttribute<NoteShared::NoteAlarmAttribute>();
-        Akonadi::ItemModifyJob *modify = new Akonadi::ItemModifyJob(item);
+        auto *modify = new Akonadi::ItemModifyJob(item);
         connect(modify, &Akonadi::ItemModifyJob::result, this, &NotesAgentAlarmDialog::slotModifyItem);
     }
 }
@@ -195,7 +182,7 @@ void NotesAgentAlarmDialog::slotModifyAlarm()
     Akonadi::Item::Id id = mListWidget->currentItemId();
     if (id != -1) {
         Akonadi::Item item(id);
-        Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+        auto *job = new Akonadi::ItemFetchJob(item, this);
         job->fetchScope().fetchFullPayload(true);
         job->fetchScope().fetchAttribute<NoteShared::NoteAlarmAttribute>();
         connect(job, &Akonadi::ItemFetchJob::result, this, &NotesAgentAlarmDialog::slotFetchAlarmItem);
@@ -208,11 +195,11 @@ void NotesAgentAlarmDialog::slotFetchAlarmItem(KJob *job)
         qCDebug(NOTESAGENT_LOG) << "fetch item failed " << job->errorString();
         return;
     }
-    Akonadi::ItemFetchJob *itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
+    auto *itemFetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
     Akonadi::Item::List items = itemFetchJob->items();
     if (!items.isEmpty()) {
         Akonadi::Item item = items.first();
-        NoteShared::NoteAlarmAttribute *attr = item.attribute<NoteShared::NoteAlarmAttribute>();
+        auto *attr = item.attribute<NoteShared::NoteAlarmAttribute>();
         if (attr) {
             KMime::Message::Ptr noteMessage = item.payload<KMime::Message::Ptr>();
             if (!noteMessage) {
@@ -234,7 +221,7 @@ void NotesAgentAlarmDialog::slotFetchAlarmItem(KJob *job)
                 } else {
                     item.removeAttribute<NoteShared::NoteAlarmAttribute>();
                 }
-                Akonadi::ItemModifyJob *modify = new Akonadi::ItemModifyJob(item);
+                auto *modify = new Akonadi::ItemModifyJob(item);
                 connect(modify, &Akonadi::ItemModifyJob::result, this, &NotesAgentAlarmDialog::slotModifyItem);
             }
             delete dlg;
