@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "notenetworkconfig.h"
@@ -48,11 +35,11 @@ NoteNetworkConfigWidget::NoteNetworkConfigWidget(QWidget *parent)
     : QWidget(parent)
     , d(new NoteShared::NoteNetworkConfigWidgetPrivate)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     QGroupBox *incoming = new QGroupBox(i18n("Incoming Notes"));
-    QHBoxLayout *tmpLayout = new QHBoxLayout;
+    auto *tmpLayout = new QHBoxLayout;
 
     d->mTmpChkB = new QCheckBox(i18n("Accept incoming notes"));
     d->mTmpChkB->setObjectName(QStringLiteral("kcfg_ReceiveNotes"));
@@ -112,9 +99,9 @@ void NoteNetworkConfigWidget::load()
 NoteNetworkConfig::NoteNetworkConfig(QWidget *parent)
     : KCModule(parent)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
+    auto *lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
-    NoteNetworkConfigWidget *noteNetworkConfigWidget = new NoteNetworkConfigWidget(this);
+    auto *noteNetworkConfigWidget = new NoteNetworkConfigWidget(this);
     lay->addWidget(noteNetworkConfigWidget);
     addConfig(NoteShared::NoteSharedGlobalConfig::self(), noteNetworkConfigWidget);
     load();
